;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "difftastic" "20251021.1320"
  "Wrapper for difftastic."
  '((emacs     "28.1")
    (compat    "29.1.4.2")
    (magit     "4.0.0")
    (transient "0.4.0"))
  :url "https://github.com/pkryger/difftastic.el"
  :commit "9cb89fcff94f68b869e214b08d7af7265b78ecbd"
  :revdesc "9cb89fcff94f"
  :keywords '("tools" "diff")
  :authors '(("Przemyslaw Kryger" . "pkryger@gmail.com"))
  :maintainers '(("Przemyslaw Kryger" . "pkryger@gmail.com")))
